spot library

Support for doing something awesome.

More dartdocs go here.

Classes

Spot
Lightweight service locator for dependency injection.
SpotContainer
A scoped DI container that supports parent-child hierarchies.
SpotDisposable
Interface for objects that require cleanup when disposed.
SpotKey<T>
Registry key that supports both unnamed and named service registration.
SpotService<T>
Represents a service that can be located type = the type of service (factory or singleton) locator = the function to instantiate the type The locator function is called lazily the first time the dependency is requested

Enums

SpotType
Type of service registration.

Functions

spot<T>({String? name}) → T
Global convenience function for resolving dependencies.
spotAsync<T>({String? name}) Future<T>
Global convenience function for resolving async dependencies.

Typedefs

SpotAsyncGetter<T> = Future<T> Function(dynamic get<R>())
Async factory function type for creating instances with async initialization.
SpotGetter<T> = T Function(dynamic get<R>())
Factory function type for creating instances.

Exceptions / Errors

SpotException
Custom exception for Spot dependency injection framework errors.