SpotContainer constructor

SpotContainer({
  1. SpotContainer? parent,
})

Creates a new container with optional parent.

If parent is provided, this container will fall back to the parent when resolving dependencies that aren't registered locally.

Implementation

SpotContainer({this.parent});