createChild method

SpotContainer createChild()

Create a child scope that inherits from this container.

The child scope will fall back to this container for dependency resolution, but can override registrations locally.

Returns: A new SpotContainer with this container as parent

Implementation

SpotContainer createChild() {
  return SpotContainer(parent: this);
}